repo_cpanel: Open a visual interface to the repo

View source: R/repo_cpanel.R

repo_cpanelR Documentation

Open a visual interface to the repo

Description

Opens a browser window with a Shiny interface to a repo. The interface is preliminary and has some exploration features together with a "Load into workspace" button for a selected item.

Usage

repo_cpanel(reporoot = NULL, env = globalenv())

Arguments

reporoot

An object of class repo. Can be NULL like for repo_open.

env

Environment to export variables to. Defaults to globalenv.

Value

Used for side effects.


repo documentation built on Aug. 5, 2026, 1:10 a.m.