Learn R Programming

repo (version 2.1.7)

repo_find: Match items by matching any field

Description

Match items by matching any field

Usage

repo_find(what, all = F, show = "ds")

Value

Used for side effects.

Arguments

what

Character to be matched against any field (see Details).

all

Show also items tagged with "hide".

show

Select columns to show.

Details

This function actually calls print specifying the find parameters. The find parameter can be any character string to be matched against any item field, including string-converted size (like "10x3").

Examples

Run this code
rp_path <- file.path(tempdir(), "example_repo")

rp <- repo_open(rp_path, TRUE)
rp$put(1, "item1", "Sample item 1", c("tag1", "tag2"))
rp$put(2, "item2", "Sample item 2", c("tag1", "hide"))
rp$put(3, "item3", "Sample item 3", c("tag2", "tag3"))
rp$print()
rp$find("tEm2")
rp$find("ag2", show="t")

## wiping the temp repo
unlink(rp_path, TRUE)

Run the code above in your browser using DataLab