Learn R Programming

repo (version 2.1.7)

repo_get: Retrieve an item from the repo.

Description

Retrieve an item from the repo.

Usage

repo_get(name, enableSuggestions = T)

Value

The previously stored object, or its file system path for attachments.

Arguments

name

An item's name.

enableSuggestions

If set to TRUE (default), enables some checks on name that are meant to gracefully handle errors and provide suggestions of similar names. If FALSE, the execution will be significantly faster in large repositories.

Examples

Run this code
rp_path <- file.path(tempdir(), "example_repo")
rp <- repo_open(rp_path, TRUE)
rp$put(1, "item1", "Sample item 1", "get")
print(rp$get("item1"))

## wiping temporary repo
unlink(rp_path, TRUE)

Run the code above in your browser using DataLab