repo_info: Provides detailed information about an item.

View source: R/repo_public.R

repo_infoR Documentation

Provides detailed information about an item.

Description

Provides detailed information about an item.

Usage

repo_info(name = NULL, tags = NULL)

Arguments

name

Item name (or list of names). If both name and tags are NULL, information about the whole repo will be provided.

tags

List of tags: info will run on all items matching the tag list.

Value

Used for side effects.

Examples

rp_path <- file.path(tempdir(), "example_repo")
rp <- repo_open(rp_path, TRUE)
rp$put(1, "item1", "Sample item 1", "info")
rp$info("item1")

## wiping temporary repo
unlink(rp_path, TRUE)

repo documentation built on Aug. 5, 2026, 1:10 a.m.