repo_pies: Plots a pie chart of repository contents

View source: R/repo_public.R

repo_piesR Documentation

Plots a pie chart of repository contents

Description

The pie chart shows all repository items as pie slices of size proportional to the item sizes on disk. Items with size smaller then 5

Usage

repo_pies(...)

Arguments

...

Other parameters passed to the pie function.

Value

Used for side effects.

Examples

## Repository creation
rp_path <- file.path(tempdir(), "example_repo")
rp <- repo_open(rp_path, TRUE)

## Producing some irrelevant data of different sizes
data1 <- 1:10
data2 <- 1:length(data1)*2
data3 <- 1:length(data1)*3

## Putting the data in the database, specifying dependencies
rp$put(data1, "item1", "First item", "repo_pies")
rp$put(data2, "item2", "Second item", "repo_pies")
rp$put(data3, "item3", "Third item", "repo_pies")

## Showing the pie chart
rp$pies()

## wiping temporary repo
unlink(rp_path, TRUE)

repo documentation built on Aug. 5, 2026, 1:10 a.m.