repo_project: Defines and 'put'-s a 'project' item.

View source: R/repo_public.R

repo_projectR Documentation

Defines and put-s a project item.

Description

A project item is a special item containing session information, including package dependencies. Every time a new item is stored in the repository, it will automatically be assigned to the current project, if one has been defined, and session information will be updated.

Usage

repo_project(name, description, replace = T)

Arguments

name

character containing the name of the project

description

character containing a longer description of the project

replace

logical, if T then an existing project item by the same name will be overwritten.

Value

Used for side effects.


repo documentation built on Aug. 5, 2026, 1:10 a.m.