Learn R Programming

repo (version 2.1.7)

repo_related: Finds all items related to a set of item

Description

Relations are defined as in the dependency graph.

Usage

repo_related(names, type = "all", excludeseed = F)

Value

A character vector of item names.

Arguments

names

A character vector of item names.

type

Can be one of "all", "to", "from". "to" recursively finds items that names is attached to. "from" recursively finds items that names depends on or is generated by. "all" finds both (connected components including names.

excludeseed

logical. If set to FALSE names will be not included in the output list.

See Also

dependencies