repo_tags: List all tags

View source: R/repo_public.R

repo_tagsR Documentation

List all tags

Description

Shows list of all unique tags associated with any item in the repository.

Usage

repo_tags(name)

Arguments

name

The name of a repository item.

Value

Character vector of unique tags defined in the repo.

See Also

repo_put

Examples

rp_path <- file.path(tempdir(), "example_repo")
rp <- repo_open(rp_path, TRUE)

## Putting two items with a few tags
rp$put(1, "item1", "Sample item 1",
    c("repo_tags", "tag1"))
rp$put(2, "item2", "Sample item 2",
    c("repo_tags", "tag2"))

## Looking up tags
rp$tags()

## wiping temporary repo
unlink(rp_path, TRUE)

repo documentation built on Aug. 5, 2026, 1:10 a.m.