| repo-package | R Documentation |
A data manager meant to avoid manual storage/retrieval of data to/from the file system. It builds one (or more) centralized repository where R objects are stored with rich annotations, including corresponding code chunks, and easily searched and retrieved. See Napolitano (2017) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1186/s12859-017-1510-6")} for further information.
The Repo package is meant to help with the management of R data files. It builds one (or more) centralized repository where R objects are stored together with corresponding annotations, tags, dependency notes, provenance traces. It also provides navigation tools to easily locate and load previously stored resources.
Create a new repository with rp <- repo_open().
Given the object rp of class repo, the repo command
foo must be called like this: rp$foo(). However, the
public name of foo will be repo_foo, and this name
must be used to get help (?repo_foo).
For a complete list of functions, use library(help = "repo").
Francesco Napolitano franapoli@gmail.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.