The previously stored object, or its file system path for
attachments.
Arguments
name
An item's name.
enableSuggestions
If set to TRUE (default), enables some
checks on name that are meant to gracefully handle
errors and provide suggestions of similar names. If FALSE, the
execution will be significantly faster in large repositories.