Learn R Programming

repo (version 2.1.7)

repo_info: Provides detailed information about an item.

Description

Provides detailed information about an item.

Usage

repo_info(name = NULL, tags = NULL)

Value

Used for side effects.

Arguments

name

Item name (or list of names). If both name and tags are NULL, information about the whole repo will be provided.

tags

List of tags: info will run on all items matching the tag list.

Examples

Run this code
rp_path <- file.path(tempdir(), "example_repo")
rp <- repo_open(rp_path, TRUE)
rp$put(1, "item1", "Sample item 1", "info")
rp$info("item1")

## wiping temporary repo
unlink(rp_path, TRUE)

Run the code above in your browser using DataLab