powered by
Provides detailed information about an item.
repo_info(name = NULL, tags = NULL)
Used for side effects.
Item name (or list of names). If both name and tags are NULL, information about the whole repo will be provided.
List of tags: info will run on all items matching the tag list.
rp_path <- file.path(tempdir(), "example_repo") rp <- repo_open(rp_path, TRUE) rp$put(1, "item1", "Sample item 1", "info") rp$info("item1") ## wiping temporary repo unlink(rp_path, TRUE)
Run the code above in your browser using DataLab